<?php



require_once 'config.php';
require_once GREEN_ZONE_DIR . 'Tests/BaseTest.php';
require_once 'Classes/Astro/Angle.php';



class TestAngle extends BaseTest
{
  public function TestIt()
  {
    $a0 = new Angle();
    $a0->FromRadians( M_PI/2.0 );
    $a1 = new Angle( $a0 );
    
    $this->PerformTest( 'Testing constructor with value',
			( $a1->ToRadians() == (M_PI/2.0) ),
			'Failed to construct with given value' );
    
    $a1->FromRadians( pi() );
    $this->PerformTest( 'Testing basic getter/setter methods ',
			( $a1->ToRadians() == M_PI ),
			'Failed to retrieve radians as set' );
    
    $this->PerformTest( 'Testing retreiving as degrees',
			( $a1->ToDegrees() == 180.0 ),
			'Failed to retreive as degrees' );
    
    $this->PerformTest( 'Testing retreiving as hms string',
			( $a1->ToHMSString() == '12:00:00' ),
			'Failed to retreive as hms string' . $a1->ToHMSString() );
    
    $this->TestDegToHMS( 171.1, 11, 24, 24 );
    $this->TestDegToHMS( 170, 11, 20, 0 );
    $this->TestDegToHMS( 180, 12, 0, 0 );
    $this->TestDegToHMS( 180.01, 12, 0, 2.4 );
    $this->TestDegToHMS( 179.99, 11, 59, 57.6 );
    
    $this->TestDegToDMS( 179.99, 179, 59, 24.0 );
    
    $this->TestFromDMSString( 179.99, '179:59:24' );
    $this->TestFromDMSString( 180.00, '180:00:00' );
    $this->TestFromDMSString( 30.0, '29:59:59' );
  }
  
  private function TestDegToHMS( $degrees, $hours_expected, $mins_expected, $secs_expected )
  {
    $a1 = new Angle();
    
    $a1->FromDegrees( $degrees );
    
    $hours = 1;
    $mins = 2;
    $secs = 3.0;
    
    $hms_string = $a1->ToHMS( $hours, $mins, $secs );
    $secs = round( $secs, 3 );
    $this->PerformTest( 'Testing Degrees To HMS conversion ' . $degrees,
			( $hours == $hours_expected && $mins == $mins_expected && $secs == $secs_expected ),
			'Failed to retreive hms by values ' . "$hours:$mins:$secs " .
			' should be ' . "$hours_expected:$mins_expected:$secs_expected" );
  }
  
  private function TestDegToDMS( $degrees, $degrees_expected, $mins_expected, $secs_expected )
  {
    $a1 = new Angle();
    
    $a1->FromDegrees( $degrees );
    
    $degrees_returned = 1;
    $mins = 2;
    $secs = 3.0;
    
    $hms_string = $a1->ToDMS( $degrees_returned, $mins, $secs );
    $secs = round( $secs, 3 );
    $this->PerformTest( 'Testing Degrees To DMS conversion ' . $degrees,
			( $degrees_returned == $degrees_expected && $mins == $mins_expected && $secs == $secs_expected ),
			'Failed to retreive hms by values ' . "$degrees_returned:$mins:$secs " .
			    ' should be ' . "$degrees_expected:$mins_expected:$secs_expected" );
  }
  
  private function TestFromDMSString( $degrees_expected, $dms_string )
  {
    $angle = new Angle();
    
    $angle->FromDMSString( $dms_string );
    $degrees_returned = round( $angle->ToDegrees(), 2 );
    $this->PerformTest( 'Testing From DMS ',
			( $degrees_returned == $degrees_expected ),
			" Failed to retreive degress from a dms got $degrees_returned expected $degrees_expected" );
  }
};

?>